==> effectv_0.3.9.orig.tar.gz: effectv-0.3.9.orig/effects/effects.h <==
/*
 * EffecTV - Realtime Digital Video Effector
 * Copyright (C) 2001-2002 FUKUCHI Kentaro
 *
 * effects.h: list of effects
 *
 */

extern effectRegisterFunc dumbRegister;
extern effectRegisterFunc quarkRegister;
extern effectRegisterFunc fireRegister;
extern effectRegisterFunc burnRegister;
extern effectRegisterFunc blurzoomRegister;
extern effectRegisterFunc baltanRegister;
extern effectRegisterFunc streakRegister;
extern effectRegisterFunc onedRegister;
extern effectRegisterFunc dotRegister;
extern effectRegisterFunc mosaicRegister;
extern effectRegisterFunc puzzleRegister;
extern effectRegisterFunc predatorRegister;
extern effectRegisterFunc spiralRegister;
extern effectRegisterFunc simuraRegister;
extern effectRegisterFunc edgeRegister;
extern effectRegisterFunc shagadelicRegister;
extern effectRegisterFunc noiseRegister;
extern effectRegisterFunc strobeRegister;
extern effectRegisterFunc agingRegister;
extern effectRegisterFunc TransFormRegister;
extern effectRegisterFunc lifeRegister;
extern effectRegisterFunc threadRegister;
extern effectRegisterFunc sparkRegister;
extern effectRegisterFunc warpRegister;
extern effectRegisterFunc holoRegister;
extern effectRegisterFunc cycleRegister;
extern effectRegisterFunc rippleRegister;
extern effectRegisterFunc diceRegister;
extern effectRegisterFunc dizzyRegister;
extern effectRegisterFunc DeinterlaceRegister;
extern effectRegisterFunc nervousRegister;
extern effectRegisterFunc rndmRegister;
extern effectRegisterFunc revRegister;
extern effectRegisterFunc rdsRegister;
extern effectRegisterFunc lensRegister;
extern effectRegisterFunc diffRegister;
extern effectRegisterFunc scrollRegister;
extern effectRegisterFunc warholRegister;
extern effectRegisterFunc matrixRegister;
extern effectRegisterFunc pupRegister;
extern effectRegisterFunc chameleonRegister;

==> effectv_0.3.11.orig.tar.gz: effectv-0.3.11/effects/effects.h <==
/*
 * EffecTV - Realtime Digital Video Effector
 * Copyright (C) 2001-2006 FUKUCHI Kentaro
 *
 * effects.h: list of effects
 *
 */

extern effectRegisterFunc dumbRegister;
extern effectRegisterFunc quarkRegister;
extern effectRegisterFunc fireRegister;
extern effectRegisterFunc burnRegister;
extern effectRegisterFunc blurzoomRegister;
extern effectRegisterFunc baltanRegister;
extern effectRegisterFunc streakRegister;
extern effectRegisterFunc onedRegister;
extern effectRegisterFunc dotRegister;
extern effectRegisterFunc mosaicRegister;
extern effectRegisterFunc puzzleRegister;
extern effectRegisterFunc predatorRegister;
extern effectRegisterFunc spiralRegister;
extern effectRegisterFunc simuraRegister;
extern effectRegisterFunc edgeRegister;
extern effectRegisterFunc shagadelicRegister;
extern effectRegisterFunc noiseRegister;
extern effectRegisterFunc strobeRegister;
extern effectRegisterFunc agingRegister;
extern effectRegisterFunc TransFormRegister;
extern effectRegisterFunc lifeRegister;
extern effectRegisterFunc threadRegister;
extern effectRegisterFunc sparkRegister;
extern effectRegisterFunc warpRegister;
extern effectRegisterFunc holoRegister;
extern effectRegisterFunc cycleRegister;
extern effectRegisterFunc rippleRegister;
extern effectRegisterFunc diceRegister;
extern effectRegisterFunc dizzyRegister;
extern effectRegisterFunc DeinterlaceRegister;
extern effectRegisterFunc nervousRegister;
extern effectRegisterFunc rndmRegister;
extern effectRegisterFunc revRegister;
extern effectRegisterFunc rdsRegister;
extern effectRegisterFunc lensRegister;
extern effectRegisterFunc diffRegister;
extern effectRegisterFunc scrollRegister;
extern effectRegisterFunc warholRegister;
extern effectRegisterFunc matrixRegister;
extern effectRegisterFunc pupRegister;
extern effectRegisterFunc chameleonRegister;
extern effectRegisterFunc opRegister;
extern effectRegisterFunc nervousHalfRegister;
extern effectRegisterFunc slofastRegister;
extern effectRegisterFunc displayWallRegister;
extern effectRegisterFunc bluescreenRegister;
extern effectRegisterFunc colstreakRegister;
extern effectRegisterFunc timeDistortionRegister;
extern effectRegisterFunc edgeBlurRegister;
